Welcome to mirror list, hosted at ThFree Co, Russian Federation.

github.com/gohugoio/locales.git - Unnamed repository; edit this file 'description' to name the repository.
summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorjoeybloggs <Dean.Karn@gmail.com>2016-08-11 00:01:13 +0300
committerjoeybloggs <Dean.Karn@gmail.com>2016-08-11 00:01:13 +0300
commitf81dd14d3cd97e875a6241cf395dae384457c455 (patch)
tree3292e3570ac0b00e3e893517a6a5934dda471886 /rules.go
parent0c695d8f7d7b0f0f955813f23d5814659e3d9bb2 (diff)
add ordinal rules + some variable cleanup
Diffstat (limited to 'rules.go')
-rw-r--r--rules.go8
1 files changed, 6 insertions, 2 deletions
diff --git a/rules.go b/rules.go
index 1397410d..80c00d98 100644
--- a/rules.go
+++ b/rules.go
@@ -40,9 +40,13 @@ type Translator interface {
// Locale returns the string value of the translator
Locale() string
// Plurals returns an array of plural rules associated
// with this translator
- Plurals() []PluralRule
+ PluralsCardinal() []PluralRule
+
+ // returns an array of ordinal plural rules associated
+ // with this translator
+ PluralsOrdinal() []PluralRule
}
// String returns the string value of PluralRule
@@ -40,9 +40,13 @@ type Translator interface {
// Locale returns the string value of the translator
Locale() string
- // Plurals returns an array of plural rules associated
+ // returns an array of cardinal plural rules associated
// with this translator